]> Sergey Matveev's repositories - nnn.git/commitdiff
Use the term auto-advance instead of auto-jump
authorArun Prakash Jana <engineerarun@gmail.com>
Wed, 15 Jun 2022 14:18:11 +0000 (19:48 +0530)
committerArun Prakash Jana <engineerarun@gmail.com>
Wed, 15 Jun 2022 14:34:56 +0000 (20:04 +0530)
There's no jump.

README.md
misc/auto-completion/fish/nnn.fish
misc/auto-completion/zsh/_nnn
nnn.1
patches/gitstatus/mainline.diff
patches/gitstatus/namefirst.diff
patches/restorepreview/mainline.diff
src/nnn.c
src/nnn.h

index 412c26b73ad68a32dcac7b05821141b41290028a..00ab86b80dba25c46af37ff8a3094286a4e17039 100644 (file)
--- a/README.md
+++ b/README.md
@@ -65,7 +65,7 @@ Runs on the Pi, [Termux](https://www.youtube.com/embed/AbaauM7gUJw) (Android), L
   - Remote mounts (needs `sshfs`, `rclone`)
   - Familiar shortcuts (arrows, <kbd>~</kbd>, <kbd>-</kbd>, <kbd>@</kbd>), quick look-up
   - `cd` on quit (*easy* shell integration)
-  - Jump to next file on file open and selection
+  - Proceed to next file on file open and selection
 - Search
   - Instant filtering with *search-as-you-type*
   - Regex (POSIX/PCRE) and string (default) filters
index 05f92ae2e889b53449f70219186472aac97c0362..c3dc6e79bfcd3a1621ca03a3810d6616e7bdce51 100644 (file)
@@ -24,7 +24,7 @@ complete -c nnn -s f    -d 'use readline history file'
 complete -c nnn -s g    -d 'regex filters'
 complete -c nnn -s H    -d 'show hidden files'
 complete -c nnn -s i    -d 'show current file info'
-complete -c nnn -s J    -d 'no auto-jump on select'
+complete -c nnn -s J    -d 'no auto-advance on selection'
 complete -c nnn -s K    -d 'detect key collision'
 complete -c nnn -s l -r -d 'lines to move per scroll'
 complete -c nnn -s n    -d 'start in type-to-nav mode'
index 8de4bdfe7e230f96e7ec3ff7a2f621f6648ef941..293fd4fb16c5061f16a5ed1a13a718157e852cb6 100644 (file)
@@ -22,7 +22,7 @@ args=(
     '(-g)-g[regex filters]'
     '(-H)-H[show hidden files]'
     '(-i)-i[show current file info]'
-    '(-J)-J[no auto-jump on select]'
+    '(-J)-J[no auto-advance on selection]'
     '(-K)-K[detect key collision]'
     '(-l)-l[lines to move per scroll]:val'
     '(-n)-n[start in type-to-nav mode]'
diff --git a/nnn.1 b/nnn.1
index 9a9b37a4f98880733c263f549de59b58f482065c..954d036b1dac554a2a2b2ff09a2d2b660cd898c0 100644 (file)
--- a/nnn.1
+++ b/nnn.1
@@ -88,7 +88,7 @@ supports the following options:
         show current file information in info bar (may be slow)
 .Pp
 .Fl J
-        disable auto-jump on selection
+        disable auto-advance on selection
         (eg. selecting an entry will no longer move cursor to the next entry)
 .Pp
 .Fl K
index 07fc3e909dca7b247fca1855241304d2a038189e..bb7bdc07ea4b7758e96b2e09d40208f0c246586a 100644 (file)
@@ -210,7 +210,7 @@ index 508ee915..77d56d63 100644
 +              " -G      always show git status\n"
                " -H      show hidden files\n"
                " -i      show current file info\n"
-               " -J      no auto-jump on selection\n"
+               " -J      no auto-advance on selection\n"
 @@ -8282,6 +8398,7 @@ static void cleanup(void)
                fflush(stdout);
        }
index 4dacfb803b56603df1f108e0ad56102993109464..00173af9c5903223d8da4d56be3135742c09139d 100644 (file)
@@ -213,7 +213,7 @@ index ee1f5beb..91aab231 100644
 +              " -G      always show git status\n"
                " -H      show hidden files\n"
                " -i      show current file info\n"
-               " -J      no auto-jump on selection\n"
+               " -J      no auto-advance on selection\n"
 @@ -8292,6 +8407,7 @@ static void cleanup(void)
                fflush(stdout);
        }
index ecac37de2a24c05491132b65ac51c2b4532ce04b..a020e748cc490eae0631829bcdf566d761de07d2 100644 (file)
@@ -11,7 +11,7 @@ index 6b0c1dc5..2aac557b 100644
 --- a/src/nnn.c
 +++ b/src/nnn.c
 @@ -372,7 +372,8 @@ typedef struct {
-       uint_t stayonsel  : 1;  /* Disable auto-jump on select */
+       uint_t stayonsel  : 1;  /* Disable auto-advance on selection */
        uint_t trash      : 2;  /* Trash method 0: rm -rf, 1: trash-cli, 2: gio trash */
        uint_t uidgid     : 1;  /* Show owner and group info */
 -      uint_t reserved   : 6;  /* Adjust when adding/removing a field */
index eb7d6e59bbcd97eba3c86da673ec08f7c58f349b..8b0db0df9582dfa1c559bf9a0965f83da9a70285 100644 (file)
--- a/src/nnn.h
+++ b/src/nnn.h
@@ -247,7 +247,7 @@ static struct key bindings[] = {
        { 'u',            SEL_UMOUNT },
        /* Show help */
        { '?',            SEL_HELP },
-       /* Toggle auto-jump on open */
+       /* Toggle auto-advance on file open */
        { CONTROL('J'),   SEL_AUTONEXT },
        /* Edit in EDITOR */
        { 'e',            SEL_EDIT },
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -350,7 +350,7 @@ typedef struct {
 /* Non-persistent program-internal states (alphabeical order) */
 typedef struct {
        uint_t autofifo   : 1;  /* Auto-create NNN_FIFO */
-       uint_t autonext   : 1;  /* Auto-jump on open */
+       uint_t autonext   : 1;  /* Auto-advance on file open */
        uint_t dircolor   : 1;  /* Current status of dir color */
        uint_t dirctx     : 1;  /* Show dirs in context color */
        uint_t duinit     : 1;  /* Initialize disk usage */
@@ -369,7 +369,7 @@ typedef struct {
        uint_t runplugin  : 1;  /* Choose plugin mode */
        uint_t selbm      : 1;  /* Select a bookmark from bookmarks directory */
        uint_t selmode    : 1;  /* Set when selecting files */
-       uint_t stayonsel  : 1;  /* Disable auto-jump on select */
+       uint_t stayonsel  : 1;  /* Disable auto-advance on selection */
        uint_t trash      : 2;  /* Trash method 0: rm -rf, 1: trash-cli, 2: gio trash */
        uint_t uidgid     : 1;  /* Show owner and group info */
        uint_t reserved   : 6;  /* Adjust when adding/removing a field */
@@ -5039,7 +5039,7 @@ static void show_help(const char *path)
               "9Lt h  Parent%-12c~ ` @ -  ~, /, start, prev\n"
           "5Ret Rt l  Open%-20c'  First file/match\n"
               "9g ^A  Top%-21c.  Toggle hidden\n"
-              "9G ^E  End%-20c^J  Toggle auto-jump on open\n"
+              "9G ^E  End%-20c^J  Toggle auto-advance on open\n"
              "8B (,)  Book(mark)%-11cb ^/  Select bookmark\n"
                "a1-4  Context%-11c(Sh)Tab  Cycle/new context\n"
            "62Esc ^Q  Quit%-20cq  Quit context\n"
@@ -8180,7 +8180,7 @@ static void usage(void)
                " -g      regex filters\n"
                " -H      show hidden files\n"
                " -i      show current file info\n"
-               " -J      no auto-jump on selection\n"
+               " -J      no auto-advance on selection\n"
                " -K      detect key collision\n"
                " -l val  set scroll lines\n"
                " -n      type-to-nav mode\n"
index 5e23cc3d0472d08e10c150f34a83a7538e1ec147..e603840f0ed708bb18f69383170ad81b350ff89a 100644 (file)